This folder contains files that used to be in the `tpie/` directory under the
root but have been declared dead code.

Since deleting the files will make it much, much harder to revert the files to
a state in which `git blame` yields useful output, they are placed here for the
next few months until we are sure no one is using them.

Mathias Rav, 23 January 2012
